import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { DataExchangeClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../DataExchangeClient";
import { CreateEventActionRequest, CreateEventActionResponse } from "../models/models_0";
export interface CreateEventActionCommandInput extends CreateEventActionRequest {
}
export interface CreateEventActionCommandOutput extends CreateEventActionResponse, __MetadataBearer {
}
/**
 * <p>This operation creates an event action.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { DataExchangeClient, CreateEventActionCommand } from "@aws-sdk/client-dataexchange"; // ES Modules import
 * // const { DataExchangeClient, CreateEventActionCommand } = require("@aws-sdk/client-dataexchange"); // CommonJS import
 * const client = new DataExchangeClient(config);
 * const command = new CreateEventActionCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link CreateEventActionCommandInput} for command's `input` shape.
 * @see {@link CreateEventActionCommandOutput} for command's `response` shape.
 * @see {@link DataExchangeClientResolvedConfig | config} for DataExchangeClient's `config` shape.
 *
 */
export declare class CreateEventActionCommand extends $Command<CreateEventActionCommandInput, CreateEventActionCommandOutput, DataExchangeClientResolvedConfig> {
    readonly input: CreateEventActionCommandInput;
    constructor(input: CreateEventActionCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: DataExchangeClientResolvedConfig, options?: __HttpHandlerOptions): Handler<CreateEventActionCommandInput, CreateEventActionCommandOutput>;
    private serialize;
    private deserialize;
}
