import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { DataExchangeClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../DataExchangeClient";
import { GetEventActionRequest, GetEventActionResponse } from "../models/models_0";
export interface GetEventActionCommandInput extends GetEventActionRequest {
}
export interface GetEventActionCommandOutput extends GetEventActionResponse, __MetadataBearer {
}
/**
 * <p>This operation retrieves information about an event action.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { DataExchangeClient, GetEventActionCommand } from "@aws-sdk/client-dataexchange"; // ES Modules import
 * // const { DataExchangeClient, GetEventActionCommand } = require("@aws-sdk/client-dataexchange"); // CommonJS import
 * const client = new DataExchangeClient(config);
 * const command = new GetEventActionCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link GetEventActionCommandInput} for command's `input` shape.
 * @see {@link GetEventActionCommandOutput} for command's `response` shape.
 * @see {@link DataExchangeClientResolvedConfig | config} for DataExchangeClient's `config` shape.
 *
 */
export declare class GetEventActionCommand extends $Command<GetEventActionCommandInput, GetEventActionCommandOutput, DataExchangeClientResolvedConfig> {
    readonly input: GetEventActionCommandInput;
    constructor(input: GetEventActionCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: DataExchangeClientResolvedConfig, options?: __HttpHandlerOptions): Handler<GetEventActionCommandInput, GetEventActionCommandOutput>;
    private serialize;
    private deserialize;
}
