import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { DataExchangeClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../DataExchangeClient";
import { RevokeRevisionRequest, RevokeRevisionResponse } from "../models/models_0";
export interface RevokeRevisionCommandInput extends RevokeRevisionRequest {
}
export interface RevokeRevisionCommandOutput extends RevokeRevisionResponse, __MetadataBearer {
}
/**
 * <p>This operation revokes subscribers' access to a revision.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { DataExchangeClient, RevokeRevisionCommand } from "@aws-sdk/client-dataexchange"; // ES Modules import
 * // const { DataExchangeClient, RevokeRevisionCommand } = require("@aws-sdk/client-dataexchange"); // CommonJS import
 * const client = new DataExchangeClient(config);
 * const command = new RevokeRevisionCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link RevokeRevisionCommandInput} for command's `input` shape.
 * @see {@link RevokeRevisionCommandOutput} for command's `response` shape.
 * @see {@link DataExchangeClientResolvedConfig | config} for DataExchangeClient's `config` shape.
 *
 */
export declare class RevokeRevisionCommand extends $Command<RevokeRevisionCommandInput, RevokeRevisionCommandOutput, DataExchangeClientResolvedConfig> {
    readonly input: RevokeRevisionCommandInput;
    constructor(input: RevokeRevisionCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: DataExchangeClientResolvedConfig, options?: __HttpHandlerOptions): Handler<RevokeRevisionCommandInput, RevokeRevisionCommandOutput>;
    private serialize;
    private deserialize;
}
