import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { DataExchangeClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../DataExchangeClient";
import { SendApiAssetRequest, SendApiAssetResponse } from "../models/models_0";
export interface SendApiAssetCommandInput extends SendApiAssetRequest {
}
export interface SendApiAssetCommandOutput extends SendApiAssetResponse, __MetadataBearer {
}
/**
 * <p>This operation invokes an API Gateway API asset. The request is proxied to the provider’s API Gateway API.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { DataExchangeClient, SendApiAssetCommand } from "@aws-sdk/client-dataexchange"; // ES Modules import
 * // const { DataExchangeClient, SendApiAssetCommand } = require("@aws-sdk/client-dataexchange"); // CommonJS import
 * const client = new DataExchangeClient(config);
 * const command = new SendApiAssetCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link SendApiAssetCommandInput} for command's `input` shape.
 * @see {@link SendApiAssetCommandOutput} for command's `response` shape.
 * @see {@link DataExchangeClientResolvedConfig | config} for DataExchangeClient's `config` shape.
 *
 */
export declare class SendApiAssetCommand extends $Command<SendApiAssetCommandInput, SendApiAssetCommandOutput, DataExchangeClientResolvedConfig> {
    readonly input: SendApiAssetCommandInput;
    constructor(input: SendApiAssetCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: DataExchangeClientResolvedConfig, options?: __HttpHandlerOptions): Handler<SendApiAssetCommandInput, SendApiAssetCommandOutput>;
    private serialize;
    private deserialize;
}
