import { ExceptionOptionType as __ExceptionOptionType } from "@aws-sdk/smithy-client";
import { DataExchangeServiceException as __BaseException } from "./DataExchangeServiceException";

export declare class AccessDeniedException extends __BaseException {
    readonly name: "AccessDeniedException";
    readonly $fault: "client";
    
    Message: string | undefined;
    
    constructor(opts: __ExceptionOptionType<AccessDeniedException, __BaseException>);
}
export declare enum ServerSideEncryptionTypes {
    AES256 = "AES256",
    aws_kms = "aws:kms"
}

export interface ExportServerSideEncryption {
    
    KmsKeyArn?: string;
    
    Type: ServerSideEncryptionTypes | string | undefined;
}
export declare namespace ExportServerSideEncryption {
    
    const filterSensitiveLog: (obj: ExportServerSideEncryption) => any;
}

export interface AutoExportRevisionDestinationEntry {
    
    Bucket: string | undefined;
    
    KeyPattern?: string;
}
export declare namespace AutoExportRevisionDestinationEntry {
    
    const filterSensitiveLog: (obj: AutoExportRevisionDestinationEntry) => any;
}

export interface AutoExportRevisionToS3RequestDetails {
    
    Encryption?: ExportServerSideEncryption;
    
    RevisionDestination: AutoExportRevisionDestinationEntry | undefined;
}
export declare namespace AutoExportRevisionToS3RequestDetails {
    
    const filterSensitiveLog: (obj: AutoExportRevisionToS3RequestDetails) => any;
}

export interface Action {
    
    ExportRevisionToS3?: AutoExportRevisionToS3RequestDetails;
}
export declare namespace Action {
    
    const filterSensitiveLog: (obj: Action) => any;
}
export declare enum ProtocolType {
    REST = "REST"
}

export interface ApiGatewayApiAsset {
    
    ApiDescription?: string;
    
    ApiEndpoint?: string;
    
    ApiId?: string;
    
    ApiKey?: string;
    
    ApiName?: string;
    
    ApiSpecificationDownloadUrl?: string;
    
    ApiSpecificationDownloadUrlExpiresAt?: Date;
    
    ProtocolType?: ProtocolType | string;
    
    Stage?: string;
}
export declare namespace ApiGatewayApiAsset {
    
    const filterSensitiveLog: (obj: ApiGatewayApiAsset) => any;
}

export interface AssetDestinationEntry {
    
    AssetId: string | undefined;
    
    Bucket: string | undefined;
    
    Key?: string;
}
export declare namespace AssetDestinationEntry {
    
    const filterSensitiveLog: (obj: AssetDestinationEntry) => any;
}

export interface RedshiftDataShareAsset {
    
    Arn: string | undefined;
}
export declare namespace RedshiftDataShareAsset {
    
    const filterSensitiveLog: (obj: RedshiftDataShareAsset) => any;
}

export interface S3SnapshotAsset {
    
    Size: number | undefined;
}
export declare namespace S3SnapshotAsset {
    
    const filterSensitiveLog: (obj: S3SnapshotAsset) => any;
}

export interface AssetDetails {
    
    S3SnapshotAsset?: S3SnapshotAsset;
    
    RedshiftDataShareAsset?: RedshiftDataShareAsset;
    
    ApiGatewayApiAsset?: ApiGatewayApiAsset;
}
export declare namespace AssetDetails {
    
    const filterSensitiveLog: (obj: AssetDetails) => any;
}
export declare enum AssetType {
    API_GATEWAY_API = "API_GATEWAY_API",
    REDSHIFT_DATA_SHARE = "REDSHIFT_DATA_SHARE",
    S3_SNAPSHOT = "S3_SNAPSHOT"
}

export interface AssetEntry {
    
    Arn: string | undefined;
    
    AssetDetails: AssetDetails | undefined;
    
    AssetType: AssetType | string | undefined;
    
    CreatedAt: Date | undefined;
    
    DataSetId: string | undefined;
    
    Id: string | undefined;
    
    Name: string | undefined;
    
    RevisionId: string | undefined;
    
    SourceId?: string;
    
    UpdatedAt: Date | undefined;
}
export declare namespace AssetEntry {
    
    const filterSensitiveLog: (obj: AssetEntry) => any;
}

export interface AssetSourceEntry {
    
    Bucket: string | undefined;
    
    Key: string | undefined;
}
export declare namespace AssetSourceEntry {
    
    const filterSensitiveLog: (obj: AssetSourceEntry) => any;
}
export interface CancelJobRequest {
    
    JobId: string | undefined;
}
export declare namespace CancelJobRequest {
    
    const filterSensitiveLog: (obj: CancelJobRequest) => any;
}
export declare enum ResourceType {
    ASSET = "ASSET",
    DATA_SET = "DATA_SET",
    EVENT_ACTION = "EVENT_ACTION",
    JOB = "JOB",
    REVISION = "REVISION"
}

export declare class ConflictException extends __BaseException {
    readonly name: "ConflictException";
    readonly $fault: "client";
    
    Message: string | undefined;
    
    ResourceId?: string;
    
    ResourceType?: ResourceType | string;
    
    constructor(opts: __ExceptionOptionType<ConflictException, __BaseException>);
}

export declare class InternalServerException extends __BaseException {
    readonly name: "InternalServerException";
    readonly $fault: "server";
    
    Message: string | undefined;
    
    constructor(opts: __ExceptionOptionType<InternalServerException, __BaseException>);
}

export declare class ResourceNotFoundException extends __BaseException {
    readonly name: "ResourceNotFoundException";
    readonly $fault: "client";
    
    Message: string | undefined;
    
    ResourceId?: string;
    
    ResourceType?: ResourceType | string;
    
    constructor(opts: __ExceptionOptionType<ResourceNotFoundException, __BaseException>);
}

export declare class ThrottlingException extends __BaseException {
    readonly name: "ThrottlingException";
    readonly $fault: "client";
    
    Message: string | undefined;
    
    constructor(opts: __ExceptionOptionType<ThrottlingException, __BaseException>);
}
export declare enum ExceptionCause {
    InsufficientS3BucketPolicy = "InsufficientS3BucketPolicy",
    S3AccessDenied = "S3AccessDenied"
}

export declare class ValidationException extends __BaseException {
    readonly name: "ValidationException";
    readonly $fault: "client";
    
    Message: string | undefined;
    
    ExceptionCause?: ExceptionCause | string;
    
    constructor(opts: __ExceptionOptionType<ValidationException, __BaseException>);
}
export declare enum Code {
    ACCESS_DENIED_EXCEPTION = "ACCESS_DENIED_EXCEPTION",
    INTERNAL_SERVER_EXCEPTION = "INTERNAL_SERVER_EXCEPTION",
    MALWARE_DETECTED = "MALWARE_DETECTED",
    MALWARE_SCAN_ENCRYPTED_FILE = "MALWARE_SCAN_ENCRYPTED_FILE",
    RESOURCE_NOT_FOUND_EXCEPTION = "RESOURCE_NOT_FOUND_EXCEPTION",
    SERVICE_QUOTA_EXCEEDED_EXCEPTION = "SERVICE_QUOTA_EXCEEDED_EXCEPTION",
    VALIDATION_EXCEPTION = "VALIDATION_EXCEPTION"
}

export interface CreateDataSetRequest {
    
    AssetType: AssetType | string | undefined;
    
    Description: string | undefined;
    
    Name: string | undefined;
    
    Tags?: {
        [key: string]: string;
    };
}
export declare namespace CreateDataSetRequest {
    
    const filterSensitiveLog: (obj: CreateDataSetRequest) => any;
}
export declare enum Origin {
    ENTITLED = "ENTITLED",
    OWNED = "OWNED"
}

export interface OriginDetails {
    
    ProductId: string | undefined;
}
export declare namespace OriginDetails {
    
    const filterSensitiveLog: (obj: OriginDetails) => any;
}
export interface CreateDataSetResponse {
    
    Arn?: string;
    
    AssetType?: AssetType | string;
    
    CreatedAt?: Date;
    
    Description?: string;
    
    Id?: string;
    
    Name?: string;
    
    Origin?: Origin | string;
    
    OriginDetails?: OriginDetails;
    
    SourceId?: string;
    
    Tags?: {
        [key: string]: string;
    };
    
    UpdatedAt?: Date;
}
export declare namespace CreateDataSetResponse {
    
    const filterSensitiveLog: (obj: CreateDataSetResponse) => any;
}
export declare enum LimitName {
    Amazon_API_Gateway_API_assets_per_revision = "Amazon API Gateway API assets per revision",
    Amazon_Redshift_datashare_assets_per_import_job_from_Redshift = "Amazon Redshift datashare assets per import job from Redshift",
    Amazon_Redshift_datashare_assets_per_revision = "Amazon Redshift datashare assets per revision",
    Asset_per_export_job_from_Amazon_S3 = "Asset per export job from Amazon S3",
    Asset_size_in_GB = "Asset size in GB",
    Assets_per_import_job_from_Amazon_S3 = "Assets per import job from Amazon S3",
    Assets_per_revision = "Assets per revision",
    Auto_export_event_actions_per_data_set = "Auto export event actions per data set",
    Concurrent_in_progress_jobs_to_export_assets_to_Amazon_S3 = "Concurrent in progress jobs to export assets to Amazon S3",
    Concurrent_in_progress_jobs_to_export_assets_to_a_signed_URL = "Concurrent in progress jobs to export assets to a signed URL",
    Concurrent_in_progress_jobs_to_export_revisions_to_Amazon_S3 = "Concurrent in progress jobs to export revisions to Amazon S3",
    Concurrent_in_progress_jobs_to_import_assets_from_Amazon_Redshift_datashares = "Concurrent in progress jobs to import assets from Amazon Redshift datashares",
    Concurrent_in_progress_jobs_to_import_assets_from_Amazon_S3 = "Concurrent in progress jobs to import assets from Amazon S3",
    Concurrent_in_progress_jobs_to_import_assets_from_a_signed_URL = "Concurrent in progress jobs to import assets from a signed URL",
    Concurrent_in_progress_jobs_to_import_assets_from_an_API_Gateway_API = "Concurrent in progress jobs to import assets from an API Gateway API",
    Data_sets_per_account = "Data sets per account",
    Data_sets_per_product = "Data sets per product",
    Event_actions_per_account = "Event actions per account",
    Products_per_account = "Products per account",
    Revisions_per_Amazon_API_Gateway_API_data_set = "Revisions per Amazon API Gateway API data set",
    Revisions_per_Amazon_Redshift_datashare_data_set = "Revisions per Amazon Redshift datashare data set",
    Revisions_per_data_set = "Revisions per data set"
}

export declare class ServiceLimitExceededException extends __BaseException {
    readonly name: "ServiceLimitExceededException";
    readonly $fault: "client";
    
    LimitName?: LimitName | string;
    
    LimitValue?: number;
    
    Message: string | undefined;
    
    constructor(opts: __ExceptionOptionType<ServiceLimitExceededException, __BaseException>);
}

export interface RevisionPublished {
    
    DataSetId: string | undefined;
}
export declare namespace RevisionPublished {
    
    const filterSensitiveLog: (obj: RevisionPublished) => any;
}

export interface Event {
    
    RevisionPublished?: RevisionPublished;
}
export declare namespace Event {
    
    const filterSensitiveLog: (obj: Event) => any;
}

export interface CreateEventActionRequest {
    
    Action: Action | undefined;
    
    Event: Event | undefined;
}
export declare namespace CreateEventActionRequest {
    
    const filterSensitiveLog: (obj: CreateEventActionRequest) => any;
}
export interface CreateEventActionResponse {
    
    Action?: Action;
    
    Arn?: string;
    
    CreatedAt?: Date;
    
    Event?: Event;
    
    Id?: string;
    
    UpdatedAt?: Date;
}
export declare namespace CreateEventActionResponse {
    
    const filterSensitiveLog: (obj: CreateEventActionResponse) => any;
}

export interface ExportAssetsToS3RequestDetails {
    
    AssetDestinations: AssetDestinationEntry[] | undefined;
    
    DataSetId: string | undefined;
    
    Encryption?: ExportServerSideEncryption;
    
    RevisionId: string | undefined;
}
export declare namespace ExportAssetsToS3RequestDetails {
    
    const filterSensitiveLog: (obj: ExportAssetsToS3RequestDetails) => any;
}

export interface ExportAssetToSignedUrlRequestDetails {
    
    AssetId: string | undefined;
    
    DataSetId: string | undefined;
    
    RevisionId: string | undefined;
}
export declare namespace ExportAssetToSignedUrlRequestDetails {
    
    const filterSensitiveLog: (obj: ExportAssetToSignedUrlRequestDetails) => any;
}

export interface RevisionDestinationEntry {
    
    Bucket: string | undefined;
    
    KeyPattern?: string;
    
    RevisionId: string | undefined;
}
export declare namespace RevisionDestinationEntry {
    
    const filterSensitiveLog: (obj: RevisionDestinationEntry) => any;
}

export interface ExportRevisionsToS3RequestDetails {
    
    DataSetId: string | undefined;
    
    Encryption?: ExportServerSideEncryption;
    
    RevisionDestinations: RevisionDestinationEntry[] | undefined;
}
export declare namespace ExportRevisionsToS3RequestDetails {
    
    const filterSensitiveLog: (obj: ExportRevisionsToS3RequestDetails) => any;
}

export interface ImportAssetFromApiGatewayApiRequestDetails {
    
    ApiDescription?: string;
    
    ApiId: string | undefined;
    
    ApiKey?: string;
    
    ApiName: string | undefined;
    
    ApiSpecificationMd5Hash: string | undefined;
    
    DataSetId: string | undefined;
    
    ProtocolType: ProtocolType | string | undefined;
    
    RevisionId: string | undefined;
    
    Stage: string | undefined;
}
export declare namespace ImportAssetFromApiGatewayApiRequestDetails {
    
    const filterSensitiveLog: (obj: ImportAssetFromApiGatewayApiRequestDetails) => any;
}

export interface ImportAssetFromSignedUrlRequestDetails {
    
    AssetName: string | undefined;
    
    DataSetId: string | undefined;
    
    Md5Hash: string | undefined;
    
    RevisionId: string | undefined;
}
export declare namespace ImportAssetFromSignedUrlRequestDetails {
    
    const filterSensitiveLog: (obj: ImportAssetFromSignedUrlRequestDetails) => any;
}

export interface RedshiftDataShareAssetSourceEntry {
    
    DataShareArn: string | undefined;
}
export declare namespace RedshiftDataShareAssetSourceEntry {
    
    const filterSensitiveLog: (obj: RedshiftDataShareAssetSourceEntry) => any;
}

export interface ImportAssetsFromRedshiftDataSharesRequestDetails {
    
    AssetSources: RedshiftDataShareAssetSourceEntry[] | undefined;
    
    DataSetId: string | undefined;
    
    RevisionId: string | undefined;
}
export declare namespace ImportAssetsFromRedshiftDataSharesRequestDetails {
    
    const filterSensitiveLog: (obj: ImportAssetsFromRedshiftDataSharesRequestDetails) => any;
}

export interface ImportAssetsFromS3RequestDetails {
    
    AssetSources: AssetSourceEntry[] | undefined;
    
    DataSetId: string | undefined;
    
    RevisionId: string | undefined;
}
export declare namespace ImportAssetsFromS3RequestDetails {
    
    const filterSensitiveLog: (obj: ImportAssetsFromS3RequestDetails) => any;
}

export interface RequestDetails {
    
    ExportAssetToSignedUrl?: ExportAssetToSignedUrlRequestDetails;
    
    ExportAssetsToS3?: ExportAssetsToS3RequestDetails;
    
    ExportRevisionsToS3?: ExportRevisionsToS3RequestDetails;
    
    ImportAssetFromSignedUrl?: ImportAssetFromSignedUrlRequestDetails;
    
    ImportAssetsFromS3?: ImportAssetsFromS3RequestDetails;
    
    ImportAssetsFromRedshiftDataShares?: ImportAssetsFromRedshiftDataSharesRequestDetails;
    
    ImportAssetFromApiGatewayApi?: ImportAssetFromApiGatewayApiRequestDetails;
}
export declare namespace RequestDetails {
    
    const filterSensitiveLog: (obj: RequestDetails) => any;
}
export declare enum Type {
    EXPORT_ASSETS_TO_S3 = "EXPORT_ASSETS_TO_S3",
    EXPORT_ASSET_TO_SIGNED_URL = "EXPORT_ASSET_TO_SIGNED_URL",
    EXPORT_REVISIONS_TO_S3 = "EXPORT_REVISIONS_TO_S3",
    IMPORT_ASSETS_FROM_REDSHIFT_DATA_SHARES = "IMPORT_ASSETS_FROM_REDSHIFT_DATA_SHARES",
    IMPORT_ASSETS_FROM_S3 = "IMPORT_ASSETS_FROM_S3",
    IMPORT_ASSET_FROM_API_GATEWAY_API = "IMPORT_ASSET_FROM_API_GATEWAY_API",
    IMPORT_ASSET_FROM_SIGNED_URL = "IMPORT_ASSET_FROM_SIGNED_URL"
}

export interface CreateJobRequest {
    
    Details: RequestDetails | undefined;
    
    Type: Type | string | undefined;
}
export declare namespace CreateJobRequest {
    
    const filterSensitiveLog: (obj: CreateJobRequest) => any;
}

export interface ExportAssetsToS3ResponseDetails {
    
    AssetDestinations: AssetDestinationEntry[] | undefined;
    
    DataSetId: string | undefined;
    
    Encryption?: ExportServerSideEncryption;
    
    RevisionId: string | undefined;
}
export declare namespace ExportAssetsToS3ResponseDetails {
    
    const filterSensitiveLog: (obj: ExportAssetsToS3ResponseDetails) => any;
}

export interface ExportAssetToSignedUrlResponseDetails {
    
    AssetId: string | undefined;
    
    DataSetId: string | undefined;
    
    RevisionId: string | undefined;
    
    SignedUrl?: string;
    
    SignedUrlExpiresAt?: Date;
}
export declare namespace ExportAssetToSignedUrlResponseDetails {
    
    const filterSensitiveLog: (obj: ExportAssetToSignedUrlResponseDetails) => any;
}

export interface ExportRevisionsToS3ResponseDetails {
    
    DataSetId: string | undefined;
    
    Encryption?: ExportServerSideEncryption;
    
    RevisionDestinations: RevisionDestinationEntry[] | undefined;
    
    EventActionArn?: string;
}
export declare namespace ExportRevisionsToS3ResponseDetails {
    
    const filterSensitiveLog: (obj: ExportRevisionsToS3ResponseDetails) => any;
}

export interface ImportAssetFromApiGatewayApiResponseDetails {
    
    ApiDescription?: string;
    
    ApiId: string | undefined;
    
    ApiKey?: string;
    
    ApiName: string | undefined;
    
    ApiSpecificationMd5Hash: string | undefined;
    
    ApiSpecificationUploadUrl: string | undefined;
    
    ApiSpecificationUploadUrlExpiresAt: Date | undefined;
    
    DataSetId: string | undefined;
    
    ProtocolType: ProtocolType | string | undefined;
    
    RevisionId: string | undefined;
    
    Stage: string | undefined;
}
export declare namespace ImportAssetFromApiGatewayApiResponseDetails {
    
    const filterSensitiveLog: (obj: ImportAssetFromApiGatewayApiResponseDetails) => any;
}

export interface ImportAssetFromSignedUrlResponseDetails {
    
    AssetName: string | undefined;
    
    DataSetId: string | undefined;
    
    Md5Hash?: string;
    
    RevisionId: string | undefined;
    
    SignedUrl?: string;
    
    SignedUrlExpiresAt?: Date;
}
export declare namespace ImportAssetFromSignedUrlResponseDetails {
    
    const filterSensitiveLog: (obj: ImportAssetFromSignedUrlResponseDetails) => any;
}

export interface ImportAssetsFromRedshiftDataSharesResponseDetails {
    
    AssetSources: RedshiftDataShareAssetSourceEntry[] | undefined;
    
    DataSetId: string | undefined;
    
    RevisionId: string | undefined;
}
export declare namespace ImportAssetsFromRedshiftDataSharesResponseDetails {
    
    const filterSensitiveLog: (obj: ImportAssetsFromRedshiftDataSharesResponseDetails) => any;
}

export interface ImportAssetsFromS3ResponseDetails {
    
    AssetSources: AssetSourceEntry[] | undefined;
    
    DataSetId: string | undefined;
    
    RevisionId: string | undefined;
}
export declare namespace ImportAssetsFromS3ResponseDetails {
    
    const filterSensitiveLog: (obj: ImportAssetsFromS3ResponseDetails) => any;
}

export interface ResponseDetails {
    
    ExportAssetToSignedUrl?: ExportAssetToSignedUrlResponseDetails;
    
    ExportAssetsToS3?: ExportAssetsToS3ResponseDetails;
    
    ExportRevisionsToS3?: ExportRevisionsToS3ResponseDetails;
    
    ImportAssetFromSignedUrl?: ImportAssetFromSignedUrlResponseDetails;
    
    ImportAssetsFromS3?: ImportAssetsFromS3ResponseDetails;
    
    ImportAssetsFromRedshiftDataShares?: ImportAssetsFromRedshiftDataSharesResponseDetails;
    
    ImportAssetFromApiGatewayApi?: ImportAssetFromApiGatewayApiResponseDetails;
}
export declare namespace ResponseDetails {
    
    const filterSensitiveLog: (obj: ResponseDetails) => any;
}

export interface ImportAssetFromSignedUrlJobErrorDetails {
    
    AssetName: string | undefined;
}
export declare namespace ImportAssetFromSignedUrlJobErrorDetails {
    
    const filterSensitiveLog: (obj: ImportAssetFromSignedUrlJobErrorDetails) => any;
}

export interface Details {
    
    ImportAssetFromSignedUrlJobErrorDetails?: ImportAssetFromSignedUrlJobErrorDetails;
    
    ImportAssetsFromS3JobErrorDetails?: AssetSourceEntry[];
}
export declare namespace Details {
    
    const filterSensitiveLog: (obj: Details) => any;
}
export declare enum JobErrorLimitName {
    Amazon_Redshift_datashare_assets_per_revision = "Amazon Redshift datashare assets per revision",
    Asset_size_in_GB = "Asset size in GB",
    Assets_per_revision = "Assets per revision"
}
export declare enum JobErrorResourceTypes {
    ASSET = "ASSET",
    DATA_SET = "DATA_SET",
    REVISION = "REVISION"
}

export interface JobError {
    
    Code: Code | string | undefined;
    
    Details?: Details;
    
    LimitName?: JobErrorLimitName | string;
    
    LimitValue?: number;
    
    Message: string | undefined;
    
    ResourceId?: string;
    
    ResourceType?: JobErrorResourceTypes | string;
}
export declare namespace JobError {
    
    const filterSensitiveLog: (obj: JobError) => any;
}
export declare enum State {
    CANCELLED = "CANCELLED",
    COMPLETED = "COMPLETED",
    ERROR = "ERROR",
    IN_PROGRESS = "IN_PROGRESS",
    TIMED_OUT = "TIMED_OUT",
    WAITING = "WAITING"
}
export interface CreateJobResponse {
    
    Arn?: string;
    
    CreatedAt?: Date;
    
    Details?: ResponseDetails;
    
    Errors?: JobError[];
    
    Id?: string;
    
    State?: State | string;
    
    Type?: Type | string;
    
    UpdatedAt?: Date;
}
export declare namespace CreateJobResponse {
    
    const filterSensitiveLog: (obj: CreateJobResponse) => any;
}

export interface CreateRevisionRequest {
    
    Comment?: string;
    
    DataSetId: string | undefined;
    
    Tags?: {
        [key: string]: string;
    };
}
export declare namespace CreateRevisionRequest {
    
    const filterSensitiveLog: (obj: CreateRevisionRequest) => any;
}
export interface CreateRevisionResponse {
    
    Arn?: string;
    
    Comment?: string;
    
    CreatedAt?: Date;
    
    DataSetId?: string;
    
    Finalized?: boolean;
    
    Id?: string;
    
    SourceId?: string;
    
    Tags?: {
        [key: string]: string;
    };
    
    UpdatedAt?: Date;
    
    RevocationComment?: string;
    
    Revoked?: boolean;
    
    RevokedAt?: Date;
}
export declare namespace CreateRevisionResponse {
    
    const filterSensitiveLog: (obj: CreateRevisionResponse) => any;
}
export interface DeleteAssetRequest {
    
    AssetId: string | undefined;
    
    DataSetId: string | undefined;
    
    RevisionId: string | undefined;
}
export declare namespace DeleteAssetRequest {
    
    const filterSensitiveLog: (obj: DeleteAssetRequest) => any;
}
export interface DeleteDataSetRequest {
    
    DataSetId: string | undefined;
}
export declare namespace DeleteDataSetRequest {
    
    const filterSensitiveLog: (obj: DeleteDataSetRequest) => any;
}
export interface DeleteEventActionRequest {
    
    EventActionId: string | undefined;
}
export declare namespace DeleteEventActionRequest {
    
    const filterSensitiveLog: (obj: DeleteEventActionRequest) => any;
}
export interface DeleteRevisionRequest {
    
    DataSetId: string | undefined;
    
    RevisionId: string | undefined;
}
export declare namespace DeleteRevisionRequest {
    
    const filterSensitiveLog: (obj: DeleteRevisionRequest) => any;
}
export interface GetAssetRequest {
    
    AssetId: string | undefined;
    
    DataSetId: string | undefined;
    
    RevisionId: string | undefined;
}
export declare namespace GetAssetRequest {
    
    const filterSensitiveLog: (obj: GetAssetRequest) => any;
}
export interface GetAssetResponse {
    
    Arn?: string;
    
    AssetDetails?: AssetDetails;
    
    AssetType?: AssetType | string;
    
    CreatedAt?: Date;
    
    DataSetId?: string;
    
    Id?: string;
    
    Name?: string;
    
    RevisionId?: string;
    
    SourceId?: string;
    
    UpdatedAt?: Date;
}
export declare namespace GetAssetResponse {
    
    const filterSensitiveLog: (obj: GetAssetResponse) => any;
}
export interface GetDataSetRequest {
    
    DataSetId: string | undefined;
}
export declare namespace GetDataSetRequest {
    
    const filterSensitiveLog: (obj: GetDataSetRequest) => any;
}
export interface GetDataSetResponse {
    
    Arn?: string;
    
    AssetType?: AssetType | string;
    
    CreatedAt?: Date;
    
    Description?: string;
    
    Id?: string;
    
    Name?: string;
    
    Origin?: Origin | string;
    
    OriginDetails?: OriginDetails;
    
    SourceId?: string;
    
    Tags?: {
        [key: string]: string;
    };
    
    UpdatedAt?: Date;
}
export declare namespace GetDataSetResponse {
    
    const filterSensitiveLog: (obj: GetDataSetResponse) => any;
}
export interface GetEventActionRequest {
    
    EventActionId: string | undefined;
}
export declare namespace GetEventActionRequest {
    
    const filterSensitiveLog: (obj: GetEventActionRequest) => any;
}
export interface GetEventActionResponse {
    
    Action?: Action;
    
    Arn?: string;
    
    CreatedAt?: Date;
    
    Event?: Event;
    
    Id?: string;
    
    UpdatedAt?: Date;
}
export declare namespace GetEventActionResponse {
    
    const filterSensitiveLog: (obj: GetEventActionResponse) => any;
}
export interface GetJobRequest {
    
    JobId: string | undefined;
}
export declare namespace GetJobRequest {
    
    const filterSensitiveLog: (obj: GetJobRequest) => any;
}
export interface GetJobResponse {
    
    Arn?: string;
    
    CreatedAt?: Date;
    
    Details?: ResponseDetails;
    
    Errors?: JobError[];
    
    Id?: string;
    
    State?: State | string;
    
    Type?: Type | string;
    
    UpdatedAt?: Date;
}
export declare namespace GetJobResponse {
    
    const filterSensitiveLog: (obj: GetJobResponse) => any;
}
export interface GetRevisionRequest {
    
    DataSetId: string | undefined;
    
    RevisionId: string | undefined;
}
export declare namespace GetRevisionRequest {
    
    const filterSensitiveLog: (obj: GetRevisionRequest) => any;
}
export interface GetRevisionResponse {
    
    Arn?: string;
    
    Comment?: string;
    
    CreatedAt?: Date;
    
    DataSetId?: string;
    
    Finalized?: boolean;
    
    Id?: string;
    
    SourceId?: string;
    
    Tags?: {
        [key: string]: string;
    };
    
    UpdatedAt?: Date;
    
    RevocationComment?: string;
    
    Revoked?: boolean;
    
    RevokedAt?: Date;
}
export declare namespace GetRevisionResponse {
    
    const filterSensitiveLog: (obj: GetRevisionResponse) => any;
}
export interface ListDataSetRevisionsRequest {
    
    DataSetId: string | undefined;
    
    MaxResults?: number;
    
    NextToken?: string;
}
export declare namespace ListDataSetRevisionsRequest {
    
    const filterSensitiveLog: (obj: ListDataSetRevisionsRequest) => any;
}

export interface RevisionEntry {
    
    Arn: string | undefined;
    
    Comment?: string;
    
    CreatedAt: Date | undefined;
    
    DataSetId: string | undefined;
    
    Finalized?: boolean;
    
    Id: string | undefined;
    
    SourceId?: string;
    
    UpdatedAt: Date | undefined;
    
    RevocationComment?: string;
    
    Revoked?: boolean;
    
    RevokedAt?: Date;
}
export declare namespace RevisionEntry {
    
    const filterSensitiveLog: (obj: RevisionEntry) => any;
}
export interface ListDataSetRevisionsResponse {
    
    NextToken?: string;
    
    Revisions?: RevisionEntry[];
}
export declare namespace ListDataSetRevisionsResponse {
    
    const filterSensitiveLog: (obj: ListDataSetRevisionsResponse) => any;
}
export interface ListDataSetsRequest {
    
    MaxResults?: number;
    
    NextToken?: string;
    
    Origin?: string;
}
export declare namespace ListDataSetsRequest {
    
    const filterSensitiveLog: (obj: ListDataSetsRequest) => any;
}

export interface DataSetEntry {
    
    Arn: string | undefined;
    
    AssetType: AssetType | string | undefined;
    
    CreatedAt: Date | undefined;
    
    Description: string | undefined;
    
    Id: string | undefined;
    
    Name: string | undefined;
    
    Origin: Origin | string | undefined;
    
    OriginDetails?: OriginDetails;
    
    SourceId?: string;
    
    UpdatedAt: Date | undefined;
}
export declare namespace DataSetEntry {
    
    const filterSensitiveLog: (obj: DataSetEntry) => any;
}
export interface ListDataSetsResponse {
    
    DataSets?: DataSetEntry[];
    
    NextToken?: string;
}
export declare namespace ListDataSetsResponse {
    
    const filterSensitiveLog: (obj: ListDataSetsResponse) => any;
}
export interface ListEventActionsRequest {
    
    EventSourceId?: string;
    
    MaxResults?: number;
    
    NextToken?: string;
}
export declare namespace ListEventActionsRequest {
    
    const filterSensitiveLog: (obj: ListEventActionsRequest) => any;
}

export interface EventActionEntry {
    
    Action: Action | undefined;
    
    Arn: string | undefined;
    
    CreatedAt: Date | undefined;
    
    Event: Event | undefined;
    
    Id: string | undefined;
    
    UpdatedAt: Date | undefined;
}
export declare namespace EventActionEntry {
    
    const filterSensitiveLog: (obj: EventActionEntry) => any;
}
export interface ListEventActionsResponse {
    
    EventActions?: EventActionEntry[];
    
    NextToken?: string;
}
export declare namespace ListEventActionsResponse {
    
    const filterSensitiveLog: (obj: ListEventActionsResponse) => any;
}
export interface ListJobsRequest {
    
    DataSetId?: string;
    
    MaxResults?: number;
    
    NextToken?: string;
    
    RevisionId?: string;
}
export declare namespace ListJobsRequest {
    
    const filterSensitiveLog: (obj: ListJobsRequest) => any;
}

export interface JobEntry {
    
    Arn: string | undefined;
    
    CreatedAt: Date | undefined;
    
    Details: ResponseDetails | undefined;
    
    Errors?: JobError[];
    
    Id: string | undefined;
    
    State: State | string | undefined;
    
    Type: Type | string | undefined;
    
    UpdatedAt: Date | undefined;
}
export declare namespace JobEntry {
    
    const filterSensitiveLog: (obj: JobEntry) => any;
}
export interface ListJobsResponse {
    
    Jobs?: JobEntry[];
    
    NextToken?: string;
}
export declare namespace ListJobsResponse {
    
    const filterSensitiveLog: (obj: ListJobsResponse) => any;
}
export interface ListRevisionAssetsRequest {
    
    DataSetId: string | undefined;
    
    MaxResults?: number;
    
    NextToken?: string;
    
    RevisionId: string | undefined;
}
export declare namespace ListRevisionAssetsRequest {
    
    const filterSensitiveLog: (obj: ListRevisionAssetsRequest) => any;
}
export interface ListRevisionAssetsResponse {
    
    Assets?: AssetEntry[];
    
    NextToken?: string;
}
export declare namespace ListRevisionAssetsResponse {
    
    const filterSensitiveLog: (obj: ListRevisionAssetsResponse) => any;
}
export interface ListTagsForResourceRequest {
    
    ResourceArn: string | undefined;
}
export declare namespace ListTagsForResourceRequest {
    
    const filterSensitiveLog: (obj: ListTagsForResourceRequest) => any;
}
export interface ListTagsForResourceResponse {
    
    Tags?: {
        [key: string]: string;
    };
}
export declare namespace ListTagsForResourceResponse {
    
    const filterSensitiveLog: (obj: ListTagsForResourceResponse) => any;
}

export interface RevokeRevisionRequest {
    
    DataSetId: string | undefined;
    
    RevisionId: string | undefined;
    
    RevocationComment: string | undefined;
}
export declare namespace RevokeRevisionRequest {
    
    const filterSensitiveLog: (obj: RevokeRevisionRequest) => any;
}
export interface RevokeRevisionResponse {
    
    Arn?: string;
    
    Comment?: string;
    
    CreatedAt?: Date;
    
    DataSetId?: string;
    
    Finalized?: boolean;
    
    Id?: string;
    
    SourceId?: string;
    
    UpdatedAt?: Date;
    
    RevocationComment?: string;
    
    Revoked?: boolean;
    
    RevokedAt?: Date;
}
export declare namespace RevokeRevisionResponse {
    
    const filterSensitiveLog: (obj: RevokeRevisionResponse) => any;
}

export interface SendApiAssetRequest {
    
    Body?: string;
    
    QueryStringParameters?: {
        [key: string]: string;
    };
    
    AssetId: string | undefined;
    
    DataSetId: string | undefined;
    
    RequestHeaders?: {
        [key: string]: string;
    };
    
    Method?: string;
    
    Path?: string;
    
    RevisionId: string | undefined;
}
export declare namespace SendApiAssetRequest {
    
    const filterSensitiveLog: (obj: SendApiAssetRequest) => any;
}
export interface SendApiAssetResponse {
    
    Body?: string;
    
    ResponseHeaders?: {
        [key: string]: string;
    };
}
export declare namespace SendApiAssetResponse {
    
    const filterSensitiveLog: (obj: SendApiAssetResponse) => any;
}
export interface StartJobRequest {
    
    JobId: string | undefined;
}
export declare namespace StartJobRequest {
    
    const filterSensitiveLog: (obj: StartJobRequest) => any;
}
export interface StartJobResponse {
}
export declare namespace StartJobResponse {
    
    const filterSensitiveLog: (obj: StartJobResponse) => any;
}

export interface TagResourceRequest {
    
    ResourceArn: string | undefined;
    
    Tags: {
        [key: string]: string;
    } | undefined;
}
export declare namespace TagResourceRequest {
    
    const filterSensitiveLog: (obj: TagResourceRequest) => any;
}
export interface UntagResourceRequest {
    
    ResourceArn: string | undefined;
    
    TagKeys: string[] | undefined;
}
export declare namespace UntagResourceRequest {
    
    const filterSensitiveLog: (obj: UntagResourceRequest) => any;
}

export interface UpdateAssetRequest {
    
    AssetId: string | undefined;
    
    DataSetId: string | undefined;
    
    Name: string | undefined;
    
    RevisionId: string | undefined;
}
export declare namespace UpdateAssetRequest {
    
    const filterSensitiveLog: (obj: UpdateAssetRequest) => any;
}
export interface UpdateAssetResponse {
    
    Arn?: string;
    
    AssetDetails?: AssetDetails;
    
    AssetType?: AssetType | string;
    
    CreatedAt?: Date;
    
    DataSetId?: string;
    
    Id?: string;
    
    Name?: string;
    
    RevisionId?: string;
    
    SourceId?: string;
    
    UpdatedAt?: Date;
}
export declare namespace UpdateAssetResponse {
    
    const filterSensitiveLog: (obj: UpdateAssetResponse) => any;
}

export interface UpdateDataSetRequest {
    
    DataSetId: string | undefined;
    
    Description?: string;
    
    Name?: string;
}
export declare namespace UpdateDataSetRequest {
    
    const filterSensitiveLog: (obj: UpdateDataSetRequest) => any;
}
export interface UpdateDataSetResponse {
    
    Arn?: string;
    
    AssetType?: AssetType | string;
    
    CreatedAt?: Date;
    
    Description?: string;
    
    Id?: string;
    
    Name?: string;
    
    Origin?: Origin | string;
    
    OriginDetails?: OriginDetails;
    
    SourceId?: string;
    
    UpdatedAt?: Date;
}
export declare namespace UpdateDataSetResponse {
    
    const filterSensitiveLog: (obj: UpdateDataSetResponse) => any;
}

export interface UpdateEventActionRequest {
    
    Action?: Action;
    
    EventActionId: string | undefined;
}
export declare namespace UpdateEventActionRequest {
    
    const filterSensitiveLog: (obj: UpdateEventActionRequest) => any;
}
export interface UpdateEventActionResponse {
    
    Action?: Action;
    
    Arn?: string;
    
    CreatedAt?: Date;
    
    Event?: Event;
    
    Id?: string;
    
    UpdatedAt?: Date;
}
export declare namespace UpdateEventActionResponse {
    
    const filterSensitiveLog: (obj: UpdateEventActionResponse) => any;
}

export interface UpdateRevisionRequest {
    
    Comment?: string;
    
    DataSetId: string | undefined;
    
    Finalized?: boolean;
    
    RevisionId: string | undefined;
}
export declare namespace UpdateRevisionRequest {
    
    const filterSensitiveLog: (obj: UpdateRevisionRequest) => any;
}
export interface UpdateRevisionResponse {
    
    Arn?: string;
    
    Comment?: string;
    
    CreatedAt?: Date;
    
    DataSetId?: string;
    
    Finalized?: boolean;
    
    Id?: string;
    
    SourceId?: string;
    
    UpdatedAt?: Date;
    
    RevocationComment?: string;
    
    Revoked?: boolean;
    
    RevokedAt?: Date;
}
export declare namespace UpdateRevisionResponse {
    
    const filterSensitiveLog: (obj: UpdateRevisionResponse) => any;
}
